@@ -5,8 +5,7 @@ import threading
 import time
 
 from livelock.connection import SocketBuffer
-from livelock.server import KEY_NOT_EXISTS
-from livelock.shared import get_settings, DEFAULT_MAX_PAYLOAD, pack_resp
+from livelock.shared import get_settings, DEFAULT_MAX_PAYLOAD, pack_resp, KEY_NOT_EXISTS
 
 logger = logging.getLogger(__name__)
 
@@ -111,7 +110,7 @@ class LiveLockConnection(object):
                     if not reconnect_attempts:
                         raise e
                     time.sleep(self._reconnect_timeout)
-            logger.debug('New socket %s' % sock)
+            logger.debug('New socket %s', sock)
             self._sock = sock
             self._sock_pid = os.getpid()
             self._buffer = SocketBuffer(sock, 65536)
@@ -120,7 +119,7 @@ class LiveLockConnection(object):
 
     def _reconnect(self, do_conn_on_reconnect=True):
         if self._sock and self._sock_pid == os.getpid():
-            logger.debug('Closing socket before reconnect %s' % self._sock)
+            logger.debug('Closing socket before reconnect %s', self._sock)
             self._sock.close()
         self._sock = None
         self._buffer = None
@@ -275,8 +274,7 @@ class LiveLockConnection(object):
                 data = self._read_response()
                 break
             except (ConnectionResetError, OSError, ConnectionError) as e:
-                capture_exception(e)
-                logger.info('Got exception on send_command: %s' % e)
+                logger.info('Got exception on send_command: %s', e)
                 reconnect_attempts -= 1
                 # Explicitly close socket, because error may be raised on send or receive phase, protocol state is unknown
                 # and disable connection reuse
